@@ -5,7 +5,7 @@ function [omega,f] = UnivariateSpectralDensity(dr,var_list)
 % 
 % Adapted from th_autocovariances.m.  
 
-% Copyright (C) 2006-2009 Dynare Team
+% Copyright (C) 2006-2011 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -93,7 +93,7 @@ for i=M_.maximum_lag:-1:2
     i0 = i1;
 end
 Gamma = zeros(nvar,cutoff+1);
-[A,B] = kalman_transition_matrix(dr,ikx',1:nx,dr.transition_auxiliary_variables,M_.exo_nbr);
+[A,B] = kalman_transition_matrix(dr,ikx',1:nx,M_.exo_nbr);
 [vx, u] =  lyapunov_symm(A,B*M_.Sigma_e*B',options_.qz_criterium,options_.lyapunov_complex_threshold);
 iky = iv(ivar);
 if ~isempty(u)
