@@ -32,7 +32,7 @@ function [dr,info,M_,options_,oo_] = dr1(dr,task,M_,options_,oo_)
 %   none.
 %  
 
-% Copyright (C) 1996-2009 Dynare Team
+% Copyright (C) 1996-2011 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -86,6 +86,7 @@ if options_.ramsey_policy
         M_.maximum_endo_lead = orig_model.maximum_endo_lead;
         M_.maximum_lag = orig_model.maximum_lag;
         M_.maximum_endo_lag = orig_model.maximum_endo_lag;
+        oo_.steady_state = oo_.steady_state(1:M_.endo_nbr);
     end
 
     if options_.steadystate_flag
@@ -97,19 +98,22 @@ if options_.ramsey_policy
         end
         ys = oo_.steady_state;
         [inst_val,info1] = dynare_solve('dyn_ramsey_static_', ...
-                                oo_.steady_state(k_inst),0, ...
-                                M_,options_,oo_,it_);
+                                        oo_.steady_state(k_inst),0, ...
+                                        M_,options_,oo_,it_);
+        M_.params = evalin('base','M_.params;');
         ys(k_inst) = inst_val;
         [x,check] = feval([M_.fname '_steadystate'],...
                           ys,[oo_.exo_steady_state; ...
                             oo_.exo_det_steady_state]);
+        M_.params = evalin('base','M_.params;');
         if size(x,1) < M_.endo_nbr 
             if length(M_.aux_vars) > 0
                 x = add_auxiliary_variables_to_steadystate(x,M_.aux_vars,...
                                                            M_.fname,...
                                                            oo_.exo_steady_state,...
                                                            oo_.exo_det_steady_state,...
-                                                           M_.params);
+                                                           M_.params,...
+                                                           options_.bytecode);
             else
                 error([M_.fname '_steadystate.m doesn''t match the model']);
             end
@@ -118,10 +122,10 @@ if options_.ramsey_policy
         [junk,junk,multbar] = dyn_ramsey_static_(oo_.steady_state(k_inst),M_,options_,oo_,it_);
     else
         [oo_.steady_state,info1] = dynare_solve('dyn_ramsey_static_', ...
-                                        oo_.steady_state,0,M_,options_,oo_,it_);
+                                                oo_.steady_state,0,M_,options_,oo_,it_);
         [junk,junk,multbar] = dyn_ramsey_static_(oo_.steady_state,M_,options_,oo_,it_);
     end
-        
+    
     check1 = max(abs(feval([M_.fname '_static'],...
                            oo_.steady_state,...
                            [oo_.exo_steady_state; ...
@@ -131,10 +135,11 @@ if options_.ramsey_policy
         info(2) = check1'*check1;
         return
     end
-
-    [jacobia_,M_] = dyn_ramsey_dynamic_(oo_.steady_state,multbar,M_,options_,oo_,it_);
+    
+    [jacobia_,M_,dr] = dyn_ramsey_dynamic_(oo_.steady_state,multbar,M_,options_,dr,it_);
     klen = M_.maximum_lag + M_.maximum_lead + 1;
     dr.ys = [oo_.steady_state;zeros(M_.exo_nbr,1);multbar];
+    oo_.steady_state = dr.ys;
 else
     klen = M_.maximum_lag + M_.maximum_lead + 1;
     iyv = M_.lead_lag_incidence';
@@ -148,14 +153,28 @@ else
     
     it_ = M_.maximum_lag + 1;
     z = repmat(dr.ys,1,klen);
-    z = z(iyr0) ;
+    if ~options_.bytecode
+        z = z(iyr0) ;
+    end;
     if options_.order == 1
-        [junk,jacobia_] = feval([M_.fname '_dynamic'],z,[oo_.exo_simul ...
-                            oo_.exo_det_simul], M_.params, it_);
+        if (options_.bytecode)
+            [chck, junk, loc_dr] = bytecode('dynamic','evaluate', z,[oo_.exo_simul ...
+                                oo_.exo_det_simul], M_.params, dr.ys, 1);
+            jacobia_ = [loc_dr.g1 loc_dr.g1_x loc_dr.g1_xd];
+        else
+            [junk,jacobia_] = feval([M_.fname '_dynamic'],z,[oo_.exo_simul ...
+                                oo_.exo_det_simul], M_.params, dr.ys, it_);
+        end;
     elseif options_.order == 2
-        [junk,jacobia_,hessian1] = feval([M_.fname '_dynamic'],z,...
-                                         [oo_.exo_simul ...
-                            oo_.exo_det_simul], M_.params, it_);
+        if (options_.bytecode)
+            [chck, junk, loc_dr] = bytecode('dynamic','evaluate', z,[oo_.exo_simul ...
+                                oo_.exo_det_simul], M_.params, dr.ys, 1);
+            jacobia_ = [loc_dr.g1 loc_dr.g1_x];
+        else
+            [junk,jacobia_,hessian1] = feval([M_.fname '_dynamic'],z,...
+                                             [oo_.exo_simul ...
+                                oo_.exo_det_simul], M_.params, dr.ys, it_);
+        end;
         if options_.use_dll
             % In USE_DLL mode, the hessian is in the 3-column sparse representation
             hessian1 = sparse(hessian1(:,1), hessian1(:,2), hessian1(:,3), ...
@@ -211,7 +230,7 @@ if M_.maximum_endo_lead == 0
         try
             [dr,aimcode]=dynAIMsolver1(jacobia_,M_,dr);
             if aimcode ~=1
-                info(1) = aimcode;
+                info(1) = convertAimCodeToInfo(aimcode);
                 info(2) = 1.0e+8;
                 return
             end
@@ -264,7 +283,7 @@ if (options_.aim_solver == 1) && (task == 0)
         % reuse some of the bypassed code and tests that may be needed 
         
         if aimcode ~=1
-            info(1) = aimcode;
+            info(1) = convertAimCodeToInfo(aimcode);
             info(2) = 1.0e+8;
             return
         end
@@ -329,7 +348,8 @@ else  % use original Dynare solver
     % 2) In  global_initialization.m, if mjdgges.m is visible exist(...)==2, 
     % this means that the DLL isn't avaiable and use_qzdiv is set to 1
     
-    [ss,tt,w,sdim,dr.eigval,info1] = mjdgges(e,d,options_.qz_criterium);
+    [err,ss,tt,w,sdim,dr.eigval,info1] = mjdgges(e,d,options_.qz_criterium);
+    mexErrCheck('mjdgges', err);
 
     if info1
         info(1) = 2;
@@ -519,7 +539,9 @@ zx=[zx; zeros(M_.exo_nbr,np);zeros(M_.exo_det_nbr,np)];
 zu=[zu; eye(M_.exo_nbr);zeros(M_.exo_det_nbr,M_.exo_nbr)];
 [nrzx,nczx] = size(zx);
 
-rhs = -sparse_hessian_times_B_kronecker_C(hessian,zx);
+[err, rhs] = sparse_hessian_times_B_kronecker_C(hessian,zx,options_.threads.kronecker.sparse_hessian_times_B_kronecker_C);
+mexErrCheck('sparse_hessian_times_B_kronecker_C', err);
+rhs = -rhs;
 
 %lhs
 n = M_.endo_nbr+sum(kstate(:,2) > M_.maximum_endo_lag+1 & kstate(:,2) < M_.maximum_endo_lag+M_.maximum_endo_lead+1);
@@ -567,7 +589,8 @@ C = hx;
 D = [rhs; zeros(n-M_.endo_nbr,size(rhs,2))];
 
 
-dr.ghxx = gensylv(2,A,B,C,D);
+[err, dr.ghxx] = gensylv(2,A,B,C,D);
+mexErrCheck('gensylv', err);
 
 %ghxu
 %rhs
@@ -576,7 +599,8 @@ hu = dr.ghu(nstatic+1:nstatic+npred,:);
 %kk = kk(1:npred,1:npred);
 %rhs = -hessian*kron(zx,zu)-f1*dr.ghxx(end-nyf+1:end,kk(:))*kron(hx(1:npred,:),hu(1:npred,:));
 
-rhs = sparse_hessian_times_B_kronecker_C(hessian,zx,zu);
+[err, rhs] = sparse_hessian_times_B_kronecker_C(hessian,zx,zu,options_.threads.kronecker.sparse_hessian_times_B_kronecker_C);
+mexErrCheck('sparse_hessian_times_B_kronecker_C', err);
 
 nyf1 = sum(kstate(:,2) == M_.maximum_endo_lag+2);
 hu1 = [hu;zeros(np-npred,M_.exo_nbr)];
@@ -584,7 +608,9 @@ hu1 = [hu;zeros(np-npred,M_.exo_nbr)];
 [nrhx,nchx] = size(hx);
 [nrhu1,nchu1] = size(hu1);
 
-B1 = B*A_times_B_kronecker_C(dr.ghxx,hx,hu1);
+[err, abcOut] = A_times_B_kronecker_C(dr.ghxx,hx,hu1,options_.threads.kronecker.A_times_B_kronecker_C);
+mexErrCheck('A_times_B_kronecker_C', err);
+B1 = B*abcOut;
 rhs = -[rhs; zeros(n-M_.endo_nbr,size(rhs,2))]-B1;
 
 
@@ -596,10 +622,11 @@ dr.ghxu = A\rhs;
 kk = reshape([1:np*np],np,np);
 kk = kk(1:npred,1:npred);
 
-rhs = sparse_hessian_times_B_kronecker_C(hessian,zu);
+[err, rhs] = sparse_hessian_times_B_kronecker_C(hessian,zu,options_.threads.kronecker.sparse_hessian_times_B_kronecker_C);
+mexErrCheck('sparse_hessian_times_B_kronecker_C', err);
 
-
-B1 = A_times_B_kronecker_C(B*dr.ghxx,hu1);
+[err, B1] = A_times_B_kronecker_C(B*dr.ghxx,hu1,options_.threads.kronecker.A_times_B_kronecker_C);
+mexErrCheck('A_times_B_kronecker_C', err);
 rhs = -[rhs; zeros(n-M_.endo_nbr,size(rhs,2))]-B1;
 
 %lhs
@@ -643,7 +670,8 @@ for i=1:M_.maximum_endo_lead
         [junk,k3a,k3] = ...
             find(M_.lead_lag_incidenceordered(M_.maximum_endo_lag+j+1,:));
         nk3a = length(k3a);
-        B1 = sparse_hessian_times_B_kronecker_C(hessian(:,kh(k3,k3)),gu(k3a,:));
+        [err, B1] = sparse_hessian_times_B_kronecker_C(hessian(:,kh(k3,k3)),gu(k3a,:),options_.threads.kronecker.sparse_hessian_times_B_kronecker_C);
+        mexErrCheck('sparse_hessian_times_B_kronecker_C', err);
         RHS = RHS + jacobia_(:,k2)*guu(k2a,:)+B1;
     end
     % LHS
@@ -657,8 +685,10 @@ for i=1:M_.maximum_endo_lead
     kk = find(kstate(:,2) == M_.maximum_endo_lag+i+1);
     gu = dr.ghx*Gu;
     [nrGu,ncGu] = size(Gu);
-    G1 = A_times_B_kronecker_C(dr.ghxx,Gu);
-    G2 = A_times_B_kronecker_C(hxx,Gu);
+    [err, G1] = A_times_B_kronecker_C(dr.ghxx,Gu,options_.threads.kronecker.A_times_B_kronecker_C);
+    mexErrCheck('A_times_B_kronecker_C', err);
+    [err, G2] = A_times_B_kronecker_C(hxx,Gu,options_.threads.kronecker.A_times_B_kronecker_C);
+    mexErrCheck('A_times_B_kronecker_C', err);
     guu = dr.ghx*Guu+G1;
     Gu = hx*Gu;
     Guu = hx*Guu;
