@@ -1,4 +1,4 @@
-function [J,M_] = dyn_ramsey_dynamic_(ys,lbar,M_,options_,oo_,it_)
+function [J,M_,dr] = dyn_ramsey_dynamic_(ys,lbar,M_,options_,dr,it_)
 % function J = dyn_ramsey_dynamic_(ys,lbar)
 % dyn_ramsey_dynamic_ sets up the Jacobian of the expanded model for optimal
 % policies. It modifies several fields of M_
@@ -13,7 +13,7 @@ function [J,M_] = dyn_ramsey_dynamic_(ys,lbar,M_,options_,oo_,it_)
 % SPECIAL REQUIREMENTS
 %     none
 
-% Copyright (C) 2003-2009 Dynare Team
+% Copyright (C) 2003-2011 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -30,6 +30,8 @@ function [J,M_] = dyn_ramsey_dynamic_(ys,lbar,M_,options_,oo_,it_)
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
+persistent old_lead_lag
+
 % retrieving model parameters
 endo_nbr = M_.endo_nbr;
 i_endo_nbr = 1:endo_nbr;
@@ -71,7 +73,8 @@ Uy = Uy';
 Uyy = reshape(Uyy,endo_nbr,endo_nbr);
 
 % retrieving derivatives of original model
-[f,fJ,fH] = feval([fname '_dynamic'],y(k),[oo_.exo_simul oo_.exo_det_simul], M_.params, it_);
+[f,fJ,fH] = feval([fname '_dynamic'],y(k),zeros(2,exo_nbr), M_.params, ys, ...
+                  it_);
 instr_nbr = endo_nbr - size(f,1);
 mult_nbr = endo_nbr-instr_nbr;
 
@@ -84,10 +87,10 @@ max_leadlag1 = max_lead1;
 % adding new variables names
 endo_names1 = endo_names;
 % adding shocks to endogenous variables
-endo_names1 = strvcat(endo_names1, exo_names);
+endo_names1 = char(endo_names1, exo_names);
 % adding multipliers names
 for i=1:mult_nbr;
-    endo_names1 = strvcat(endo_names1,['mult_' int2str(i)]);
+    endo_names1 = char(endo_names1,['mult_' int2str(i)]);
 end
 
 % expanding matrix of lead/lag incidence
@@ -211,7 +214,7 @@ k = 1:size(J,2);
 
 for i=1:n
     if sum(abs(J(:,i))) < 1e-8
-        if m(i) < n1 | m(i) > n2
+        if m(i) < n1 || m(i) > n2
             k(i) = 0;
             m(i) = 0;
         end
@@ -223,6 +226,17 @@ i_leadlag1 = zeros(size(i_leadlag1))';
 i_leadlag1(nonzeros(m)) = 1:nnz(m);
 i_leadlag1 = i_leadlag1';
 
+%eliminating lags in t-2 and leads in t+2, if possible
+if all(i_leadlag1(5,:)==0)
+    i_leadlag1 = i_leadlag1(1:4,:);
+    max_lead1 = 1;
+end
+
+if all(i_leadlag1(1,:)==0)
+    i_leadlag1 = i_leadlag1(2:4,:);
+    max_lag1 = 1;
+end
+
 % setting expanded model parameters
 % storing original values
 M_.endo_nbr = endo_nbr1;
@@ -237,3 +251,31 @@ M_.maximum_endo_lead = max_lead1;
 M_.maximum_lag = max_lag1;
 M_.maximum_endo_lag = max_lag1;
 M_.orig_model = orig_model;
+
+if isfield(options_,'varobs') && (any(size(i_leadlag1,2) ~= size(old_lead_lag,2)) || any(any(i_leadlag1 ~= old_lead_lag)))
+    global bayestopt_
+    dr = set_state_space(dr,M_);
+    nstatic = dr.nstatic;          % Number of static variables. 
+    npred = dr.npred;              % Number of predetermined variables.
+
+    var_obs_index = [];
+    k1 = [];
+    for i=1:size(options_.varobs,1);
+        var_obs_index = [var_obs_index strmatch(deblank(options_.varobs(i,:)),M_.endo_names(dr.order_var,:),'exact')];
+        k1 = [k1 strmatch(deblank(options_.varobs(i,:)),M_.endo_names, 'exact')];
+    end
+    % Define union of observed and state variables
+    k2 = union(var_obs_index',[nstatic+1:nstatic+npred]');
+    % Set restrict_state to postion of observed + state variables in expanded state vector.
+    dr.restrict_var_list = k2;
+    [junk,ic] = intersect(k2,nstatic+(1:npred)');
+    dr.restrict_columns = ic;
+    % set mf0 to positions of state variables in restricted state vector for likelihood computation.
+    [junk,bayestopt_.mf0] = ismember([dr.nstatic+1:dr.nstatic+dr.npred]',k2);
+    % Set mf1 to positions of observed variables in restricted state vector for likelihood computation.
+    [junk,bayestopt_.mf1] = ismember(var_obs_index,k2); 
+    % Set mf2 to positions of observed variables in expanded state vector for filtering and smoothing.
+    bayestopt_.mf2  = var_obs_index;
+    bayestopt_.mfys = k1;
+    old_lead_lag = i_leadlag1;
+end
\ No newline at end of file
