@@ -1,6 +1,6 @@
 function osr(var_list,params,i_var,W)
 
-% Copyright (C) 2001-2006 Dynare Team
+% Copyright (C) 2001-2010 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -27,12 +27,15 @@ options_ = set_default_option(options_,'drop',100);
 options_ = set_default_option(options_,'replic',1);
 options_ = set_default_option(options_,'nomoments',0);
 options_ = set_default_option(options_,'nocorr',0);
-options_ = set_default_option(options_,'simul_seed',[]);
 options_ = set_default_option(options_,'hp_filter',0);
 options_ = set_default_option(options_,'hp_ngrid',512);
 options_ = set_default_option(options_,'simul',0);
 options_ = set_default_option(options_,'periods',1);
 
+if isempty(options_.qz_criterium)
+    options_.qz_criterium = 1+1e-6;
+end
+
 make_ex_;
 
 np = size(params,1);
