@@ -17,7 +17,7 @@ function dyn_data_01=read_variables(file_name_01,var_names_01,dyn_data_01,xls_sh
 % all local variables have complicated names in order to avoid name
 % conflicts with possible user variable names
 
-% Copyright (C) 2005-2009 Dynare Team
+% Copyright (C) 2005-2011 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -50,7 +50,7 @@ if exist(file_name_01)
     eval(dyn_instr_01);
     for dyn_i_01=1:var_size_01
         dyn_tmp_01 = eval(var_names_01(dyn_i_01,:));
-        if length(dyn_tmp_01) > dyn_size_01 & dyn_size_01 > 0
+        if length(dyn_tmp_01) > dyn_size_01 && dyn_size_01 > 0
             cd(old_pwd)
             error('data size is too large')
         end
@@ -61,7 +61,7 @@ elseif exist([file_name_01 '.mat'])
     s = load(file_name_01);
     for dyn_i_01=1:var_size_01
         dyn_tmp_01 = s.(deblank(var_names_01(dyn_i_01,:)));
-        if length(dyn_tmp_01) > dyn_size_01 & dyn_size_01 > 0
+        if length(dyn_tmp_01) > dyn_size_01 && dyn_size_01 > 0
             cd(old_pwd)
             error('data size is too large')
         end
@@ -73,7 +73,7 @@ elseif exist([file_name_01 '.xls'])
     for dyn_i_01=1:var_size_01
         iv = strmatch(var_names_01(dyn_i_01,:),raw(1,:),'exact');
         dyn_tmp_01 = [raw{2:end,iv}]';
-        if length(dyn_tmp_01) > dyn_size_01 & dyn_size_01 > 0
+        if length(dyn_tmp_01) > dyn_size_01 && dyn_size_01 > 0
             cd(old_pwd)
             error('data size is too large')
         end
