@@ -15,7 +15,7 @@ function sim1
 % SPECIAL REQUIREMENTS
 %   None.
 
-% Copyright (C) 1996-2009 Dynare Team
+% Copyright (C) 1996-2010 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -33,7 +33,6 @@ function sim1
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
 global M_ options_ oo_
-global  iyp iyf M_ it_ c
 
 lead_lag_incidence = M_.lead_lag_incidence;
 
@@ -69,14 +68,15 @@ for iter = 1:options_.maxit_
     
     it_ = it_init ;
     z = [oo_.endo_simul(iyp,it_-1) ; oo_.endo_simul(:,it_) ; oo_.endo_simul(iyf,it_+1)] ;
-    [d1,jacobian] = feval([M_.fname '_dynamic'],z,oo_.exo_simul, M_.params, it_);
+    [d1,jacobian] = feval([M_.fname '_dynamic'],z,oo_.exo_simul, M_.params, oo_.steady_state,it_);
     jacobian = [jacobian(:,iz) -d1] ;
     ic = [1:ny] ;
     icp = iyp ;
     c (ic,:) = jacobian(:,is)\jacobian(:,isf1) ;
     for it_ = it_init+(1:options_.periods-1)
         z = [oo_.endo_simul(iyp,it_-1) ; oo_.endo_simul(:,it_) ; oo_.endo_simul(iyf,it_+1)] ;
-        [d1,jacobian] = feval([M_.fname '_dynamic'],z,oo_.exo_simul, M_.params, it_);
+        [d1,jacobian] = feval([M_.fname '_dynamic'],z,oo_.exo_simul, ...
+                              M_.params, oo_.steady_state, it_);
         jacobian = [jacobian(:,iz) -d1] ;
         jacobian(:,[isf nrs]) = jacobian(:,[isf nrs])-jacobian(:,isp)*c(icp,:) ;
         ic = ic + ny ;
@@ -89,11 +89,11 @@ for iter = 1:options_.maxit_
         s(:,isf) = s(:,isf)+c(ic,1:nyf) ;
         ic = ic + ny ;
         c(ic,nrc) = s\c(ic,nrc) ;
-        c = bksup1(ny,nrc) ;
+        c = bksup1(c,ny,nrc,iyf,options_.periods) ;
         c = reshape(c,ny,options_.periods+1) ;
         oo_.endo_simul(:,it_init+(0:options_.periods)) = oo_.endo_simul(:,it_init+(0:options_.periods))+options_.slowc*c ;
     else
-        c = bksup1(ny,nrc) ;
+        c = bksup1(c,ny,nrc,iyf,options_.periods) ;
         c = reshape(c,ny,options_.periods) ;
         oo_.endo_simul(:,it_init+(0:options_.periods-1)) = oo_.endo_simul(:,it_init+(0:options_.periods-1))+options_.slowc*c ;
     end
@@ -128,6 +128,4 @@ if ~stop
     oo_.deterministic_simulation.iterations = options_.maxit_;
 end
 disp (['-----------------------------------------------------']) ;
-return ;
 
-% 08/24/01 MJ added start_simul
\ No newline at end of file
