@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2010 Dynare Team
+ * Copyright (C) 2003-2011 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -35,6 +35,7 @@ SteadyStatement::SteadyStatement(const OptionsList &options_list_arg) :
 void
 SteadyStatement::checkPass(ModFileStructure &mod_file_struct)
 {
+  mod_file_struct.steady_present = true;
 }
 
 void
@@ -95,7 +96,7 @@ void
 SimulStatement::writeOutput(ostream &output, const string &basename) const
 {
   options_list.writeOutput(output);
-  output << "simul(oo_.dr);\n";
+  output << "simul();\n";
 }
 
 StochSimulStatement::StochSimulStatement(const SymbolList &symbol_list_arg,
@@ -111,7 +112,7 @@ StochSimulStatement::checkPass(ModFileStructure &mod_file_struct)
   mod_file_struct.stoch_simul_present = true;
 
   // Fill in option_order of mod_file_struct
-  OptionsList::num_options_type::const_iterator it = options_list.num_options.find("order");
+  OptionsList::num_options_t::const_iterator it = options_list.num_options.find("order");
   if (it != options_list.num_options.end())
     mod_file_struct.order_option = max(mod_file_struct.order_option, atoi(it->second.c_str()));
 
@@ -125,6 +126,24 @@ StochSimulStatement::checkPass(ModFileStructure &mod_file_struct)
   if ((it != options_list.num_options.end() && it->second == "1")
       || mod_file_struct.order_option >= 3)
     mod_file_struct.k_order_solver = true;
+
+  // Check that option "pruning" is not used with k-order
+  it = options_list.num_options.find("pruning");
+  if ((it != options_list.num_options.end() && it->second == "1")
+      && mod_file_struct.k_order_solver)
+    {
+      cerr << "ERROR: in 'stoch_simul', you cannot use option 'pruning' with 'k_order_solver' option or with 3rd order approximation" << endl;
+      exit(EXIT_FAILURE);
+    }
+
+  // Workaround for ticket #157
+  it = options_list.num_options.find("periods");
+  if (it != options_list.num_options.end() && atoi(it->second.c_str()) > 0
+      && mod_file_struct.histval_present)
+    {
+      cerr << "ERROR: the 'periods' option of 'stoch_simul' is not compatible with a 'histval' block" << endl;
+      exit(EXIT_FAILURE);
+    }
 }
 
 void
@@ -165,7 +184,7 @@ RamseyPolicyStatement::checkPass(ModFileStructure &mod_file_struct)
   /* Fill in option_order of mod_file_struct
      Since ramsey policy needs one further order of derivation (for example, for 1st order
      approximation, it needs 2nd derivatives), we add 1 to the order declared by user */
-  OptionsList::num_options_type::const_iterator it = options_list.num_options.find("order");
+  OptionsList::num_options_t::const_iterator it = options_list.num_options.find("order");
   if (it != options_list.num_options.end())
     {
       int order = atoi(it->second.c_str());
@@ -198,9 +217,11 @@ RamseyPolicyStatement::writeOutput(ostream &output, const string &basename) cons
 }
 
 EstimationStatement::EstimationStatement(const SymbolList &symbol_list_arg,
-                                         const OptionsList &options_list_arg) :
+                                         const OptionsList &options_list_arg,
+                                         const SymbolTable &symbol_table_arg) :
   symbol_list(symbol_list_arg),
-  options_list(options_list_arg)
+  options_list(options_list_arg),
+  symbol_table(symbol_table_arg)
 {
 }
 
@@ -210,7 +231,7 @@ EstimationStatement::checkPass(ModFileStructure &mod_file_struct)
   mod_file_struct.estimation_present = true;
 
   // Fill in option_order of mod_file_struct
-  OptionsList::num_options_type::const_iterator it = options_list.num_options.find("order");
+  OptionsList::num_options_t::const_iterator it = options_list.num_options.find("order");
   if (it != options_list.num_options.end())
     mod_file_struct.order_option = max(mod_file_struct.order_option, atoi(it->second.c_str()));
 
@@ -218,6 +239,38 @@ EstimationStatement::checkPass(ModFileStructure &mod_file_struct)
   it = options_list.num_options.find("partial_information");
   if (it != options_list.num_options.end() && it->second == "1")
     mod_file_struct.partial_information = true;
+
+  // Fill in mod_file_struct.dsge_var_calibrated
+  it = options_list.num_options.find("dsge_var");
+  if (it != options_list.num_options.end())
+    mod_file_struct.dsge_var_calibrated = it->second;
+
+  // Fill in mod_file_struct.dsge_var_estimated
+  OptionsList::string_options_t::const_iterator it_str = options_list.string_options.find("dsge_var");
+  if (it_str != options_list.string_options.end())
+    mod_file_struct.dsge_var_estimated = true;
+
+  // Fill in mod_file_struct.bayesian_irf_present
+  it = options_list.num_options.find("bayesian_irf");
+  if (it != options_list.num_options.end() && it->second == "1")
+    mod_file_struct.bayesian_irf_present = true;
+
+  it = options_list.num_options.find("dsge_varlag");
+  if (it != options_list.num_options.end())
+    if (mod_file_struct.dsge_var_calibrated.empty()
+        && !mod_file_struct.dsge_var_estimated)
+      {
+        cerr << "ERROR: The estimation statement requires a dsge_var option to be passed "
+             << "if the dsge_varlag option is passed." << endl;
+        exit(EXIT_FAILURE);
+      }
+
+  if (!mod_file_struct.dsge_var_calibrated.empty()
+      && mod_file_struct.dsge_var_estimated)
+    {
+      cerr << "ERROR: An estimation statement cannot take more than one dsge_var option." << endl;
+      exit(EXIT_FAILURE);
+    }
 }
 
 void
@@ -236,7 +289,7 @@ DynareSensitivityStatement::DynareSensitivityStatement(const OptionsList &option
 void
 DynareSensitivityStatement::checkPass(ModFileStructure &mod_file_struct)
 {
-  OptionsList::num_options_type::const_iterator it = options_list.num_options.find("identification");
+  OptionsList::num_options_t::const_iterator it = options_list.num_options.find("identification");
   if (it != options_list.num_options.end()
       && it->second == "1")
     mod_file_struct.identification_present = true;
@@ -302,39 +355,38 @@ DsampleStatement::writeOutput(ostream &output, const string &basename) const
     output << "dsample(" << val1 << ", " << val2 << ");" << endl;
 }
 
-VarobsStatement::VarobsStatement(const SymbolList &symbol_list_arg) :
-  symbol_list(symbol_list_arg)
-{
-}
-
-void
-VarobsStatement::writeOutput(ostream &output, const string &basename) const
-{
-  symbol_list.writeOutput("options_.varobs", output);
-}
-
 EstimatedParamsStatement::EstimatedParamsStatement(const vector<EstimationParams> &estim_params_list_arg,
                                                    const SymbolTable &symbol_table_arg) :
   estim_params_list(estim_params_list_arg),
   symbol_table(symbol_table_arg)
+{
+}
+
+void
+EstimatedParamsStatement::checkPass(ModFileStructure &mod_file_struct)
 {
   for (vector<EstimationParams>::const_iterator it = estim_params_list.begin();
        it != estim_params_list.end(); it++)
-    // Handle case of degenerate beta prior
-    if (it->prior == "1") //BETA_PDF is associated with "1" in DynareBison.yy
-      try
-        {
-          if (it->mean->eval(eval_context_type()) == 0.5 &&
-              it->std->eval(eval_context_type()) == 0.5)
-            {
-              cerr << "ERROR: The prior density is not defined for the beta distribution when the mean = standard deviation = 0.5." << endl;
-              exit(EXIT_FAILURE);
-            }
-        }
-      catch (ExprNode::EvalException &e)
-        {
-          // We don't have enough information to compute the numerical value, skip the test
-        }
+    {
+      if (it->name == "dsge_prior_weight")
+        mod_file_struct.dsge_prior_weight_in_estimated_params = true;
+
+      // Handle case of degenerate beta prior
+      if (it->prior == "1") //BETA_PDF is associated with "1" in DynareBison.yy
+        try
+          {
+            if (it->mean->eval(eval_context_t()) == 0.5
+                && it->std->eval(eval_context_t()) == 0.5)
+              {
+                cerr << "ERROR: The prior density is not defined for the beta distribution when the mean = standard deviation = 0.5." << endl;
+                exit(EXIT_FAILURE);
+              }
+          }
+        catch (ExprNode::EvalException &e)
+          {
+            // We don't have enough information to compute the numerical value, skip the test
+          }
+    }
 }
 
 void
@@ -345,8 +397,7 @@ EstimatedParamsStatement::writeOutput(ostream &output, const string &basename) c
          << "estim_params_.var_endo = [];" << endl
          << "estim_params_.corrx = [];" << endl
          << "estim_params_.corrn = [];" << endl
-         << "estim_params_.param_vals = [];" << endl
-         << "M_.H = 0;" << endl;
+         << "estim_params_.param_vals = [];" << endl;
 
   vector<EstimationParams>::const_iterator it;
 
@@ -544,7 +595,7 @@ EstimatedParamsBoundsStatement::writeOutput(ostream &output, const string &basen
     }
 }
 
-ObservationTrendsStatement::ObservationTrendsStatement(const trend_elements_type &trend_elements_arg,
+ObservationTrendsStatement::ObservationTrendsStatement(const trend_elements_t &trend_elements_arg,
                                                        const SymbolTable &symbol_table_arg) :
   trend_elements(trend_elements_arg),
   symbol_table(symbol_table_arg)
@@ -556,7 +607,7 @@ ObservationTrendsStatement::writeOutput(ostream &output, const string &basename)
 {
   output << "options_.trend_coeff_ = {};" << endl;
 
-  trend_elements_type::const_iterator it;
+  trend_elements_t::const_iterator it;
 
   for (it = trend_elements.begin(); it != trend_elements.end(); it++)
     {
@@ -573,131 +624,6 @@ ObservationTrendsStatement::writeOutput(ostream &output, const string &basename)
     }
 }
 
-CalibVarStatement::CalibVarStatement(const calib_var_type &calib_var_arg,
-                                     const calib_covar_type &calib_covar_arg,
-                                     const calib_ac_type &calib_ac_arg,
-                                     const SymbolTable &symbol_table_arg) :
-  calib_var(calib_var_arg),
-  calib_covar(calib_covar_arg),
-  calib_ac(calib_ac_arg),
-  symbol_table(symbol_table_arg)
-{
-}
-
-void
-CalibVarStatement::writeOutput(ostream &output, const string &basename) const
-{
-
-  output << "%" << endl
-         << "% CALIB_VAR" << endl
-         << "%" << endl;
-
-  for (int i = 1; i < 4; i++)
-    {
-      output << "calib_var_index{" << i << "} = [];\n";
-      output << "calib_targets{" << i << "} = [];\n";
-      output << "calib_weights{" << i << "}=[];\n";
-    }
-
-  // Print calibration variances
-  for (calib_var_type::const_iterator it = calib_var.begin();
-       it != calib_var.end(); it++)
-    {
-      const string &name = it->first;
-      const string &weight = it->second.first;
-      const NodeID expression = it->second.second;
-
-      int id = symbol_table.getTypeSpecificID(name) + 1;
-      if (symbol_table.getType(name) == eEndogenous)
-        {
-          output << "calib_var_index{1} = [calib_var_index{1};" <<  id << "," << id << "];\n";
-          output << "calib_weights{1} = [calib_weights{1}; " << weight << "];\n";
-          output << "calib_targets{1} =[calib_targets{1}; ";
-          expression->writeOutput(output);
-          output << "];\n";
-        }
-      else if (symbol_table.getType(name) == eExogenous)
-        {
-          output << "calib_var_index{3} = [calib_var_index{3};" <<  id << "," << id << "];\n";
-          output << "calib_weights{3} = [calib_weights{3}; " << weight << "];\n";
-          output << "calib_targets{3} =[calib_targets{3}; ";
-          expression->writeOutput(output);
-          output << "];\n";
-        }
-    }
-
-  // Print calibration covariances
-  for (calib_covar_type::const_iterator it = calib_covar.begin();
-       it != calib_covar.end(); it++)
-    {
-      const string &name1 = it->first.first;
-      const string &name2 = it->first.second;
-      const string &weight = it->second.first;
-      const NodeID expression = it->second.second;
-
-      int id1 = symbol_table.getTypeSpecificID(name1) + 1;
-      int id2 = symbol_table.getTypeSpecificID(name2) + 1;
-      if (symbol_table.getType(name1) == eEndogenous)
-        {
-          output << "calib_var_index{1} = [calib_var_index{1};" <<  id1 << "," << id2 << "];\n";
-          output << "calib_weights{1} = [calib_weights{1}; " << weight << "];\n";
-          output << "calib_targets{1} =[calib_targets{1}; ";
-          expression->writeOutput(output);
-          output << "];\n";
-        }
-      else if (symbol_table.getType(name1) == eExogenous)
-        {
-          output << "calib_var_index{3} = [calib_var_index{3};" <<  id1 << "," << id2 << "];\n";
-          output << "calib_weights{3} = [calib_weights{3}; " << weight << "];\n";
-          output << "calib_targets{3} =[calib_targets{3}; ";
-          expression->writeOutput(output);
-          output << "];\n";
-        }
-    }
-
-  // Print calibration autocorrelations
-  int max_iar = 3;
-
-  for (calib_ac_type::const_iterator it = calib_ac.begin();
-       it != calib_ac.end(); it++)
-    {
-      const string &name = it->first.first;
-      int iar = it->first.second + 3;
-      const string &weight = it->second.first;
-      const NodeID expression = it->second.second;
-
-      int id = symbol_table.getTypeSpecificID(name) + 1;
-
-      if (iar > max_iar)
-        {
-          // Create new variables
-          for (int i = max_iar + 1; i <= iar; i++)
-            {
-              output << "calib_var_index{" << i << "} = [];\n";
-              output << "calib_targets{" << i << "} = [];\n";
-              output << "calib_weights{" << i << "}=[];\n";
-            }
-          max_iar = iar;
-        }
-
-      output << "calib_var_index{" << iar << "} = [calib_var_index{" << iar << "};" <<  id << "];\n";
-      output << "calib_weights{" << iar << "} = [calib_weights{" << iar << "}; " << weight << "];\n";
-      output << "calib_targets{" << iar << "} =[calib_targets{" << iar << "}; ";
-      expression->writeOutput(output);
-      output << "];\n";
-    }
-}
-
-CalibStatement::CalibStatement(int covar_arg) : covar(covar_arg)
-{
-}
-
-void
-CalibStatement::writeOutput(ostream &output, const string &basename) const
-{
-  output << "M_.Sigma_e=calib(calib_var_index,calib_targets,calib_weights," << covar << ",Sigma_e_);\n";
-}
-
 OsrParamsStatement::OsrParamsStatement(const SymbolList &symbol_list_arg) :
   symbol_list(symbol_list_arg)
 {
@@ -722,7 +648,7 @@ OsrStatement::checkPass(ModFileStructure &mod_file_struct)
   mod_file_struct.osr_present = true;
 
   // Fill in option_order of mod_file_struct
-  OptionsList::num_options_type::const_iterator it = options_list.num_options.find("order");
+  OptionsList::num_options_t::const_iterator it = options_list.num_options.find("order");
   if (it != options_list.num_options.end())
     mod_file_struct.order_option = max(mod_file_struct.order_option, atoi(it->second.c_str()));
 
@@ -746,8 +672,8 @@ OsrStatement::writeOutput(ostream &output, const string &basename) const
   output << "osr(var_list_,osr_params_,obj_var_,optim_weights_);\n";
 }
 
-OptimWeightsStatement::OptimWeightsStatement(const var_weights_type &var_weights_arg,
-                                             const covar_weights_type &covar_weights_arg,
+OptimWeightsStatement::OptimWeightsStatement(const var_weights_t &var_weights_arg,
+                                             const covar_weights_t &covar_weights_arg,
                                              const SymbolTable &symbol_table_arg) :
   var_weights(var_weights_arg),
   covar_weights(covar_weights_arg),
@@ -764,11 +690,11 @@ OptimWeightsStatement::writeOutput(ostream &output, const string &basename) cons
          << "optim_weights_ = sparse(M_.endo_nbr,M_.endo_nbr);" << endl
          << "obj_var_ = [];" << endl << endl;
 
-  for (var_weights_type::const_iterator it = var_weights.begin();
+  for (var_weights_t::const_iterator it = var_weights.begin();
        it != var_weights.end(); it++)
     {
       const string &name = it->first;
-      const NodeID value = it->second;
+      const expr_t value = it->second;
       int id = symbol_table.getTypeSpecificID(name) + 1;
       output <<  "optim_weights_(" << id << "," << id << ") = ";
       value->writeOutput(output);
@@ -776,12 +702,12 @@ OptimWeightsStatement::writeOutput(ostream &output, const string &basename) cons
       output << "obj_var_ = [obj_var_; " << id << "];\n";
     }
 
-  for (covar_weights_type::const_iterator it = covar_weights.begin();
+  for (covar_weights_t::const_iterator it = covar_weights.begin();
        it != covar_weights.end(); it++)
     {
       const string &name1 = it->first.first;
       const string &name2 = it->first.second;
-      const NodeID value = it->second;
+      const expr_t value = it->second;
       int id1 = symbol_table.getTypeSpecificID(name1) + 1;
       int id2 = symbol_table.getTypeSpecificID(name2) + 1;
       output <<  "optim_weights_(" << id1 << "," << id2 << ") = ";
@@ -821,7 +747,7 @@ DynaTypeStatement::writeOutput(ostream &output, const string &basename) const
          << "',var_list_);" << endl;
 }
 
-ModelComparisonStatement::ModelComparisonStatement(const filename_list_type &filename_list_arg,
+ModelComparisonStatement::ModelComparisonStatement(const filename_list_t &filename_list_arg,
                                                    const OptionsList &options_list_arg) :
   filename_list(filename_list_arg),
   options_list(options_list_arg)
@@ -836,7 +762,7 @@ ModelComparisonStatement::writeOutput(ostream &output, const string &basename) c
   output << "ModelNames_ = {};" << endl;
   output << "ModelPriors_ = [];" << endl;
 
-  for (filename_list_type::const_iterator it = filename_list.begin();
+  for (filename_list_t::const_iterator it = filename_list.begin();
        it != filename_list.end(); it++)
     {
       output << "ModelNames_ = { ModelNames_{:} '" << (*it).first << "'};" << endl;
@@ -864,7 +790,7 @@ PlannerObjectiveStatement::checkPass(ModFileStructure &mod_file_struct)
 void
 PlannerObjectiveStatement::computingPass()
 {
-  model_tree->computingPass(eval_context_type(), false, true, false);
+  model_tree->computingPass(eval_context_t(), false, true, false, false);
 }
 
 void
@@ -987,14 +913,17 @@ WriteLatexStaticModelStatement::writeOutput(ostream &output, const string &basen
   static_model.writeLatexFile(basename);
 }
 
-ShockDecompositionStatement::ShockDecompositionStatement(const SymbolList &symbol_list_arg) :
-  symbol_list(symbol_list_arg)
+ShockDecompositionStatement::ShockDecompositionStatement(const SymbolList &symbol_list_arg,
+                                                         const OptionsList &options_list_arg) :
+  symbol_list(symbol_list_arg),
+  options_list(options_list_arg)
 {
 }
 
 void
 ShockDecompositionStatement::writeOutput(ostream &output, const string &basename) const
 {
+  options_list.writeOutput(output);
   symbol_list.writeOutput("var_list_", output);
   output << "oo_ = shock_decomposition(M_,oo_,options_,var_list_);\n";
 }
@@ -1027,7 +956,7 @@ PlotConditionalForecastStatement::writeOutput(ostream &output, const string &bas
     output << "plot_icforecast(var_list_, " << periods << ");" << endl;
 }
 
-SvarIdentificationStatement::SvarIdentificationStatement(const svar_identification_exclusion_type &exclusion_arg,
+SvarIdentificationStatement::SvarIdentificationStatement(const svar_identification_exclusion_t &exclusion_arg,
                                                          const bool &upper_cholesky_present_arg,
                                                          const bool &lower_cholesky_present_arg,
                                                          const SymbolTable &symbol_table_arg) :
@@ -1042,7 +971,7 @@ int
 SvarIdentificationStatement::getMaxLag() const
 {
   int max_lag = 0;
-  for (svar_identification_exclusion_type::const_iterator it = exclusion.begin(); it != exclusion.end(); it++)
+  for (svar_identification_exclusion_t::const_iterator it = exclusion.begin(); it != exclusion.end(); it++)
     if (it->first.first > max_lag)
       max_lag = it->first.first;
 
@@ -1083,7 +1012,8 @@ SvarIdentificationStatement::writeOutput(ostream &output, const string &basename
   if (!upper_cholesky_present && !lower_cholesky_present)
     {
       int n = symbol_table.endo_nbr();
-      int m = symbol_table.exo_nbr();
+      //       int m = symbol_table.exo_nbr();
+      int m = 1; // this is the constant, not the shocks
       int r = getMaxLag();
       int k = r*n+m;
 
@@ -1105,7 +1035,7 @@ SvarIdentificationStatement::writeOutput(ostream &output, const string &basename
       output << "options_.ms.Qi = zeros(" << n << ", " << n << ", " << n << ");" << endl;
       output << "options_.ms.Ri = zeros(" << k << ", " << k << ", " << n << ");" << endl;
 
-      for (svar_identification_exclusion_type::const_iterator it = exclusion.begin(); it != exclusion.end(); it++)
+      for (svar_identification_exclusion_t::const_iterator it = exclusion.begin(); it != exclusion.end(); it++)
         {
           for (unsigned int h = 0; h < it->second.size(); h++)
             {
@@ -1123,7 +1053,7 @@ SvarIdentificationStatement::writeOutput(ostream &output, const string &basename
                 }
 
               if (it->first.first == 0)
-                output << "options_.ms.Qi(" << h+1 << ", " << j << ", "<< i << ");" << endl;
+                output << "options_.ms.Qi(" << h+1 << ", " << j << ", "<< i << ") = 1;" << endl;
               else if (it->first.first > 0)
                 {
                   if ((it->first.first-1)*n+j > k)
@@ -1131,7 +1061,7 @@ SvarIdentificationStatement::writeOutput(ostream &output, const string &basename
                       cerr << "ERROR: lag =" << it->first.first << ", num endog vars = " << n << "current endog var index = " << j << ". Index "
                            << "out of bounds. If the above does not represent a logical error, please report this to the Dyanre Team." << endl;
                     }
-                  output << "options_.ms.Ri(" << h+1 << ", " << (it->first.first-1)*n+j << ", "<< i << ");" << endl;
+                  output << "options_.ms.Ri(" << h+1 << ", " << (it->first.first-1)*n+j << ", "<< i << ") = 1;" << endl;
                 }
               else
                 {
@@ -1151,7 +1081,7 @@ MarkovSwitchingStatement::MarkovSwitchingStatement(const OptionsList &options_li
 void
 MarkovSwitchingStatement::writeOutput(ostream &output, const string &basename) const
 {
-  OptionsList::num_options_type::const_iterator itChain, itState, itNOS, itDuration;
+  OptionsList::num_options_t::const_iterator itChain, itState, itNOS, itDuration;
 
   itChain = options_list.num_options.find("ms.chain");
   if (itChain == options_list.num_options.end())
@@ -1191,8 +1121,8 @@ SvarStatement::SvarStatement(const OptionsList &options_list_arg) :
 void
 SvarStatement::writeOutput(ostream &output, const string &basename) const
 {
-  OptionsList::num_options_type::const_iterator it0, it1, it2;
-  OptionsList::vec_int_options_type::const_iterator itv;
+  OptionsList::num_options_t::const_iterator it0, it1, it2;
+  OptionsList::vec_int_options_t::const_iterator itv;
 
   it0 = options_list.num_options.find("ms.chain");
   if (it0 != options_list.num_options.end())
