@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2009 Dynare Team
+ * Copyright (C) 2006-2011 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -22,12 +22,15 @@
 #include <fstream>
 #include <typeinfo>
 #include "ModFile.hh"
+#include "ConfigFile.hh"
 
-ModFile::ModFile() : expressions_tree(symbol_table, num_constants),
-                     static_model(symbol_table, num_constants),
-                     dynamic_model(symbol_table, num_constants),
+ModFile::ModFile() : expressions_tree(symbol_table, num_constants, external_functions_table),
+                     dynamic_model(symbol_table, num_constants, external_functions_table),
+                     trend_dynamic_model(symbol_table, num_constants, external_functions_table),
+                     static_model(symbol_table, num_constants, external_functions_table),
+                     steady_state_model(symbol_table, num_constants, external_functions_table, static_model),
                      linear(false), block(false), byte_code(false),
-                     use_dll(false)
+                     use_dll(false), no_static(false), nonstationary_variables(false)
 {
 }
 
@@ -85,6 +88,12 @@ ModFile::addStatement(Statement *st)
   statements.push_back(st);
 }
 
+void
+ModFile::addStatementAtFront(Statement *st)
+{
+  statements.insert(statements.begin(), st);
+}
+
 void
 ModFile::checkPass()
 {
@@ -92,6 +101,9 @@ ModFile::checkPass()
        it != statements.end(); it++)
     (*it)->checkPass(mod_file_struct);
 
+  // Check the steady state block
+  steady_state_model.checkPass(mod_file_struct.ramsey_policy_present);
+
   // If order option has not been set, default to 2
   if (!mod_file_struct.order_option)
     mod_file_struct.order_option = 2;
@@ -117,9 +129,9 @@ ModFile::checkPass()
       exit(EXIT_FAILURE);
     }
 
-  if (mod_file_struct.k_order_solver && !use_dll)
+  if (mod_file_struct.k_order_solver && byte_code)
     {
-      cerr << "ERROR: When using option 'k_order_solver' (which is implicit if order >= 3), you must specify option 'use_dll' on the 'model' block" << endl;
+      cerr << "ERROR: 'k_order_solver' (which is implicit if order >= 3), is not yet compatible with 'bytecode'." << endl;
       exit(EXIT_FAILURE);
     }
 
@@ -129,11 +141,65 @@ ModFile::checkPass()
       exit(EXIT_FAILURE);
     }
 
-  if (byte_code && !block)
+  if ((stochastic_statement_present || mod_file_struct.check_present || mod_file_struct.steady_present) && no_static)
     {
-      cerr << "ERROR: In 'model' block, can't use option 'bytecode' without option 'block'" << endl;
+      cerr << "ERROR: no_static option is incompatible with stoch_simul, estimation, osr, ramsey_policy, steady and check commands" << endl;
       exit(EXIT_FAILURE);
     }
+
+  if (mod_file_struct.dsge_var_estimated)
+    if (!mod_file_struct.dsge_prior_weight_in_estimated_params)
+      {
+        cerr << "ERROR: When estimating a DSGE-VAR model and estimating the weight of the prior, dsge_prior_weight must "
+             << "be referenced in the estimated_params block." << endl;
+        exit(EXIT_FAILURE);
+      }
+
+  if (symbol_table.exists("dsge_prior_weight"))
+    {
+      if (symbol_table.getType("dsge_prior_weight") != eParameter)
+        {
+          cerr << "ERROR: dsge_prior_weight may only be used as a parameter." << endl;
+          exit(EXIT_FAILURE);
+        }
+      else
+        cout << "WARNING: When estimating a DSGE-Var, declaring dsge_prior_weight as a parameter is deprecated. "
+             <<  "The preferred method is to do this via the dsge_var option in the estimation statement." << endl;
+
+      if (mod_file_struct.dsge_var_estimated || !mod_file_struct.dsge_var_calibrated.empty())
+        {
+          cerr << "ERROR: dsge_prior_weight can either be declared as a parameter (deprecated) or via the dsge_var option "
+               << "to the estimation statement (preferred), but not both." << endl;
+          exit(EXIT_FAILURE);
+        }
+
+      if (!mod_file_struct.dsge_prior_weight_initialized && !mod_file_struct.dsge_prior_weight_in_estimated_params)
+        {
+          cerr << "ERROR: If dsge_prior_weight is declared as a parameter, it must either be initialized or placed in the "
+               << "estimated_params block." << endl;
+          exit(EXIT_FAILURE);
+        }
+
+      if (mod_file_struct.dsge_prior_weight_initialized && mod_file_struct.dsge_prior_weight_in_estimated_params)
+        {
+          cerr << "ERROR: dsge_prior_weight cannot be both initalized and estimated." << endl;
+          exit(EXIT_FAILURE);
+        }
+    }
+
+  if (mod_file_struct.dsge_prior_weight_in_estimated_params)
+    if (!mod_file_struct.dsge_var_estimated && !mod_file_struct.dsge_var_calibrated.empty())
+      {
+        cerr << "ERROR: If dsge_prior_weight is in the estimated_params block, the prior weight cannot be calibrated "
+             << "via the dsge_var option in the estimation statement." << endl;
+        exit(EXIT_FAILURE);
+      }
+    else if (!mod_file_struct.dsge_var_estimated && !symbol_table.exists("dsge_prior_weight"))
+      {
+        cerr << "ERROR: If dsge_prior_weight is in the estimated_params block, it must either be declared as a parameter "
+             << "(deprecated) or the dsge_var option must be passed to the estimation statement (preferred)." << endl;
+        exit(EXIT_FAILURE);
+      }
 }
 
 void
@@ -145,17 +211,46 @@ ModFile::transformPass()
   // Create auxiliary vars for Expectation operator
   dynamic_model.substituteExpectation(mod_file_struct.partial_information);
 
+  if (nonstationary_variables)
+    {
+      dynamic_model.detrendEquations();
+      dynamic_model.cloneDynamic(trend_dynamic_model);
+      dynamic_model.removeTrendVariableFromEquations();
+    }
+
   if (mod_file_struct.stoch_simul_present
       || mod_file_struct.estimation_present
       || mod_file_struct.osr_present
       || mod_file_struct.ramsey_policy_present)
     {
-      // In stochastic models, create auxiliary vars for leads and lags greater than 2
-      dynamic_model.substituteEndoLeadGreaterThanTwo();
-      dynamic_model.substituteExoLead();
-      dynamic_model.substituteEndoLagGreaterThanTwo();
-      dynamic_model.substituteExoLag();
+      // In stochastic models, create auxiliary vars for leads and lags greater than 2, on both endos and exos
+      dynamic_model.substituteEndoLeadGreaterThanTwo(false);
+      dynamic_model.substituteExoLead(false);
+      dynamic_model.substituteEndoLagGreaterThanTwo(false);
+      dynamic_model.substituteExoLag(false);
     }
+  else
+    {
+      // In deterministic models, create auxiliary vars for leads and lags endogenous greater than 2, only on endos (useless on exos)
+      dynamic_model.substituteEndoLeadGreaterThanTwo(true);
+      dynamic_model.substituteEndoLagGreaterThanTwo(true);
+    }
+
+  if (mod_file_struct.dsge_var_estimated || !mod_file_struct.dsge_var_calibrated.empty())
+    try
+      {
+        int sid = symbol_table.addSymbol("dsge_prior_weight", eParameter);
+        if (!mod_file_struct.dsge_var_calibrated.empty())
+          addStatementAtFront(new InitParamStatement(sid,
+                                                     expressions_tree.AddNonNegativeConstant(mod_file_struct.dsge_var_calibrated),
+                                                     symbol_table));
+      }
+    catch (SymbolTable::AlreadyDeclaredException &e)
+      {
+        cerr << "ERROR: dsge_prior_weight should not be declared as a model variable / parameter "
+             << "when the dsge_var option is passed to the estimation statement." << endl;
+        exit(EXIT_FAILURE);
+      }
 
   // Freeze the symbol table
   symbol_table.freeze();
@@ -172,8 +267,32 @@ ModFile::transformPass()
       cerr << "ERROR: There are " << dynamic_model.equation_number() << " equations but " << symbol_table.endo_nbr() << " endogenous variables!" << endl;
       exit(EXIT_FAILURE);
     }
-
+  
+  if (symbol_table.exo_det_nbr() > 0 && mod_file_struct.simul_present)
+    {
+      cerr << "ERROR: A .mod file cannot contain both a simul command and varexo_det declaration (all exogenous variables are deterministic in this case)" << endl;
+      exit(EXIT_FAILURE);
+    }
+  
   cout << "Found " << dynamic_model.equation_number() << " equation(s)." << endl;
+
+  if (symbol_table.exists("dsge_prior_weight"))
+    if (mod_file_struct.bayesian_irf_present)
+      {
+        if (symbol_table.exo_nbr() != symbol_table.observedVariablesNbr())
+          {
+            cerr << "ERROR: When estimating a DSGE-Var and the bayesian_irf option is passed to the estimation "
+                 << "statement, the number of shocks must equal the number of observed variables." << endl;
+            exit(EXIT_FAILURE);
+          }
+      }
+    else
+      if (symbol_table.exo_nbr() < symbol_table.observedVariablesNbr())
+        {
+          cerr << "ERROR: When estimating a DSGE-Var, the number of shocks must be "
+               << "greater than or equal to the number of observed variables." << endl;
+          exit(EXIT_FAILURE);
+        }
 }
 
 void
@@ -185,14 +304,22 @@ ModFile::computingPass(bool no_tmp_terms)
     || mod_file_struct.ramsey_policy_present || mod_file_struct.identification_present;
   if (dynamic_model.equation_number() > 0)
     {
+      if (nonstationary_variables)
+        trend_dynamic_model.runTrendTest(global_eval_context);
+
       // Compute static model and its derivatives
       dynamic_model.toStatic(static_model);
-      static_model.computingPass(global_eval_context, no_tmp_terms, false, block);
+      if (!no_static)
+        {
+          static_model.initializeVariablesAndEquations();
+          static_model.computingPass(global_eval_context, no_tmp_terms, false, block, byte_code);
+        }
       // Set things to compute for dynamic model
       if (dynamic_model_needed)
         {
+          dynamic_model.initializeVariablesAndEquations();
           if (mod_file_struct.simul_present)
-            dynamic_model.computingPass(false, false, false, false, global_eval_context, no_tmp_terms, block, use_dll);
+            dynamic_model.computingPass(true, false, false, false, global_eval_context, no_tmp_terms, block, use_dll, byte_code);
           else
             {
               if (mod_file_struct.order_option < 1 || mod_file_struct.order_option > 3)
@@ -203,11 +330,11 @@ ModFile::computingPass(bool no_tmp_terms)
               bool hessian = mod_file_struct.order_option >= 2 || mod_file_struct.identification_present;
               bool thirdDerivatives = mod_file_struct.order_option == 3;
               bool paramsDerivatives = mod_file_struct.identification_present;
-              dynamic_model.computingPass(true, hessian, thirdDerivatives, paramsDerivatives, global_eval_context, no_tmp_terms, false, use_dll);
+              dynamic_model.computingPass(true, hessian, thirdDerivatives, paramsDerivatives, global_eval_context, no_tmp_terms, block, use_dll, byte_code);
             }
         }
       else
-        dynamic_model.computingPass(true, true, false, false, global_eval_context, no_tmp_terms, false, false);
+        dynamic_model.computingPass(true, true, false, false, global_eval_context, no_tmp_terms, false, false, byte_code);
     }
 
   for (vector<Statement *>::iterator it = statements.begin();
@@ -216,7 +343,7 @@ ModFile::computingPass(bool no_tmp_terms)
 }
 
 void
-ModFile::writeOutputFiles(const string &basename, bool clear_all
+ModFile::writeOutputFiles(const string &basename, bool clear_all, bool console, const ConfigFile &config_file
 #if defined(_WIN32) || defined(__CYGWIN32__)
                           , bool cygwin, bool msvc
 #endif
@@ -269,10 +396,23 @@ ModFile::writeOutputFiles(const string &basename, bool clear_all
               << "end" << endl
               << "diary(logname_)" << endl;
 
+  if (console)
+    mOutputFile << "options_.console_mode = 1;" << endl;
+
   cout << "Processing outputs ...";
 
   symbol_table.writeOutput(mOutputFile);
 
+  // Initialize M_.Sigma_e and M_.H
+  mOutputFile << "M_.Sigma_e = zeros(" << symbol_table.exo_nbr() << ", "
+              << symbol_table.exo_nbr() << ");" << endl;
+
+  if (mod_file_struct.calibrated_measurement_errors)
+    mOutputFile << "M_.H = zeros(" << symbol_table.observedVariablesNbr() << ", "
+                << symbol_table.observedVariablesNbr() << ");" << endl;
+  else
+    mOutputFile << "M_.H = 0;" << endl;
+
   if (linear == 1)
     mOutputFile << "options_.linear = 1;" << endl;
 
@@ -280,13 +420,15 @@ ModFile::writeOutputFiles(const string &basename, bool clear_all
               << "options_.bytecode=" << byte_code << ";" << endl
               << "options_.use_dll=" << use_dll << ";" << endl;
 
+  config_file.writeCluster(mOutputFile);
+
   if (byte_code)
     mOutputFile << "if exist('bytecode') ~= 3" << endl
                 << "  error('DYNARE: Can''t find bytecode DLL. Please compile it or remove the ''bytecode'' option.')" << endl
                 << "end" << endl;
 
   // Erase possible remnants of previous runs
-  if (block || byte_code)
+  if (block || byte_code || use_dll)
     mOutputFile << "if exist('" << basename << "_dynamic.m', 'file')" << endl
                 << "    delete('" << basename << "_dynamic.m');" << endl
                 << "end" << endl;
@@ -333,9 +475,9 @@ ModFile::writeOutputFiles(const string &basename, bool clear_all
       // Some mex commands are enclosed in an eval(), because otherwise it will make Octave fail
 #if defined(_WIN32) || defined(__CYGWIN32__)
       if (msvc)
-        mOutputFile << "    eval('mex -O LINKFLAGS=\"$LINKFLAGS /export:Dynamic\" " << basename << "_dynamic.c')" << endl;                                                                                                                                                                                                                                                       // MATLAB/Windows + Microsoft Visual C++
+        mOutputFile << "    eval('mex -O LINKFLAGS=\"$LINKFLAGS /export:Dynamic\" " << basename << "_dynamic.c')" << endl;                                                                                                                                                                                                                                                                                                                                                                                   // MATLAB/Windows + Microsoft Visual C++
       else if (cygwin)
-        mOutputFile << "    eval('mex -O PRELINK_CMDS1=\"echo EXPORTS > mex.def & echo mexFunction >> mex.def & echo Dynamic >> mex.def\" " << basename << "_dynamic.c')" << endl;                                                                                                                                                                                                                                                                                                                                                                        // MATLAB/Windows + Cygwin g++
+        mOutputFile << "    eval('mex -O PRELINK_CMDS1=\"echo EXPORTS > mex.def & echo mexFunction >> mex.def & echo Dynamic >> mex.def\" " << basename << "_dynamic.c')" << endl;                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            // MATLAB/Windows + Cygwin g++
       else
         mOutputFile << "    error('When using the USE_DLL option, you must give either ''cygwin'' or ''msvc'' option to the ''dynare'' command')" << endl;
 #else
@@ -363,7 +505,7 @@ ModFile::writeOutputFiles(const string &basename, bool clear_all
         dynamic_model.writeOutput(mOutputFile, basename, block, byte_code, use_dll, mod_file_struct.order_option);
       else
         dynamic_model.writeOutput(mOutputFile, basename, false, false, false, mod_file_struct.order_option);
-      if (!byte_code)
+      if (!no_static)
         static_model.writeOutput(mOutputFile, block);
     }
 
@@ -377,22 +519,25 @@ ModFile::writeOutputFiles(const string &basename, bool clear_all
       InitValStatement *ivs = dynamic_cast<InitValStatement *>(*it);
       if (ivs != NULL)
         {
-          static_model.writeAuxVarInitval(mOutputFile);
+          static_model.writeAuxVarInitval(mOutputFile, oMatlabOutsideModel);
           ivs->writeOutputPostInit(mOutputFile);
         }
 
       // Special treatment for load params and steady state statement: insert initial values for the auxiliary variables
       LoadParamsAndSteadyStateStatement *lpass = dynamic_cast<LoadParamsAndSteadyStateStatement *>(*it);
-      if (lpass)
-        static_model.writeAuxVarInitval(mOutputFile);
+      if (lpass && !no_static)
+        static_model.writeAuxVarInitval(mOutputFile, oMatlabOutsideModel);
     }
 
   // Remove path for block option with M-files
   if (block && !byte_code)
     mOutputFile << "rmpath " << basename << ";" << endl;
 
-  mOutputFile << "save('" << basename << "_results.mat', 'oo_', 'M_', 'options_');" << endl
-              << "diary off" << endl
+  mOutputFile << "save('" << basename << "_results.mat', 'oo_', 'M_', 'options_');" << endl;
+
+  config_file.writeEndParallel(mOutputFile);
+
+  mOutputFile << "diary off" << endl
               << endl << "disp(['Total computing time : ' dynsec2hms(toc) ]);" << endl;
 
   mOutputFile.close();
@@ -400,7 +545,8 @@ ModFile::writeOutputFiles(const string &basename, bool clear_all
   // Create static and dynamic files
   if (dynamic_model.equation_number() > 0)
     {
-      static_model.writeStaticFile(basename, block, byte_code);
+      if (!no_static)
+        static_model.writeStaticFile(basename, block, byte_code);
 
       if (dynamic_model_needed)
         {
@@ -414,5 +560,8 @@ ModFile::writeOutputFiles(const string &basename, bool clear_all
         }
     }
 
+  // Create steady state file
+  steady_state_model.writeSteadyStateFile(basename, mod_file_struct.ramsey_policy_present);
+
   cout << "done" << endl;
 }
