@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2009 Dynare Team
+ * Copyright (C) 2003-2010 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -26,7 +26,7 @@ using namespace std;
 #include "Shocks.hh"
 
 AbstractShocksStatement::AbstractShocksStatement(bool mshocks_arg,
-                                                 const det_shocks_type &det_shocks_arg,
+                                                 const det_shocks_t &det_shocks_arg,
                                                  const SymbolTable &symbol_table_arg) :
   mshocks(mshocks_arg),
   det_shocks(det_shocks_arg),
@@ -39,18 +39,18 @@ AbstractShocksStatement::writeDetShocks(ostream &output) const
 {
   int exo_det_length = 0;
 
-  for (det_shocks_type::const_iterator it = det_shocks.begin();
+  for (det_shocks_t::const_iterator it = det_shocks.begin();
        it != det_shocks.end(); it++)
     {
       int id = symbol_table.getTypeSpecificID(it->first) + 1;
       bool exo_det = (symbol_table.getType(it->first) == eExogenousDet);
       int set_shocks_index = ((int) mshocks) + 2 * ((int) exo_det);
 
-      for (unsigned int i = 0; i < it->second.size(); i++)
+      for (size_t i = 0; i < it->second.size(); i++)
         {
           const int &period1 = it->second[i].period1;
           const int &period2 = it->second[i].period2;
-          const NodeID value = it->second[i].value;
+          const expr_t value = it->second[i].value;
 
           if (period1 == period2)
             {
@@ -74,17 +74,11 @@ AbstractShocksStatement::writeDetShocks(ostream &output) const
   output << "M_.exo_det_length = " << exo_det_length << ";\n";
 }
 
-void
-AbstractShocksStatement::checkPass(ModFileStructure &mod_file_struct)
-{
-  mod_file_struct.shocks_present = true;
-}
-
-ShocksStatement::ShocksStatement(const det_shocks_type &det_shocks_arg,
-                                 const var_and_std_shocks_type &var_shocks_arg,
-                                 const var_and_std_shocks_type &std_shocks_arg,
-                                 const covar_and_corr_shocks_type &covar_shocks_arg,
-                                 const covar_and_corr_shocks_type &corr_shocks_arg,
+ShocksStatement::ShocksStatement(const det_shocks_t &det_shocks_arg,
+                                 const var_and_std_shocks_t &var_shocks_arg,
+                                 const var_and_std_shocks_t &std_shocks_arg,
+                                 const covar_and_corr_shocks_t &covar_shocks_arg,
+                                 const covar_and_corr_shocks_t &corr_shocks_arg,
                                  const SymbolTable &symbol_table_arg) :
   AbstractShocksStatement(false, det_shocks_arg, symbol_table_arg),
   var_shocks(var_shocks_arg),
@@ -113,60 +107,122 @@ ShocksStatement::writeOutput(ostream &output, const string &basename) const
     output << "M_.sigma_e_is_diagonal = 1;" << endl;
 }
 
+void
+ShocksStatement::writeVarOrStdShock(ostream &output, var_and_std_shocks_t::const_iterator &it,
+                                    bool stddev) const
+{
+  SymbolType type = symbol_table.getType(it->first);
+  assert(type == eExogenous || symbol_table.isObservedVariable(it->first));
+
+  int id;
+  if (type == eExogenous)
+    {
+      output << "M_.Sigma_e(";
+      id = symbol_table.getTypeSpecificID(it->first) + 1;
+    }
+  else
+    {
+      output << "M_.H(";
+      id = symbol_table.getObservedVariableIndex(it->first) + 1;
+    }
+
+  output << id << ", " << id << ") = ";
+  if (stddev)
+    output << "(";
+  it->second->writeOutput(output);
+  if (stddev)
+    output << ")^2";
+  output << ";" << endl;
+}
+
 void
 ShocksStatement::writeVarAndStdShocks(ostream &output) const
 {
-  var_and_std_shocks_type::const_iterator it;
+  var_and_std_shocks_t::const_iterator it;
 
   for (it = var_shocks.begin(); it != var_shocks.end(); it++)
-    {
-      int id = symbol_table.getTypeSpecificID(it->first) + 1;
-      const NodeID value = it->second;
-      output << "M_.Sigma_e(" << id << ", " << id << ") = ";
-      value->writeOutput(output);
-      output << ";" << endl;
-    }
+    writeVarOrStdShock(output, it, false);
 
   for (it = std_shocks.begin(); it != std_shocks.end(); it++)
+    writeVarOrStdShock(output, it, true);
+}
+
+void
+ShocksStatement::writeCovarOrCorrShock(ostream &output, covar_and_corr_shocks_t::const_iterator &it,
+                                       bool corr) const
+{
+  SymbolType type1 = symbol_table.getType(it->first.first);
+  SymbolType type2 = symbol_table.getType(it->first.second);
+  assert((type1 == eExogenous && type2 == eExogenous)
+         || (symbol_table.isObservedVariable(it->first.first) && symbol_table.isObservedVariable(it->first.second)));
+  string matrix;
+  int id1, id2;
+  if (type1 == eExogenous)
     {
-      int id = symbol_table.getTypeSpecificID(it->first) + 1;
-      const NodeID value = it->second;
-      output << "M_.Sigma_e(" << id << ", " << id << ") = (";
-      value->writeOutput(output);
-      output << ")^2;" << endl;
+      matrix = "M_.Sigma_e";
+      id1 = symbol_table.getTypeSpecificID(it->first.first) + 1;
+      id2 = symbol_table.getTypeSpecificID(it->first.second) + 1;
     }
+  else
+    {
+      matrix = "M_.H";
+      id1 = symbol_table.getObservedVariableIndex(it->first.first) + 1;
+      id2 = symbol_table.getObservedVariableIndex(it->first.second) + 1;
+    }
+
+  output << matrix << "(" << id1 << ", " << id2 << ") = ";
+  it->second->writeOutput(output);
+  if (corr)
+    output << "*sqrt(" << matrix << "(" << id1 << ", " << id1 << ")*"
+           << matrix << "(" << id2 << ", " << id2 << "))";
+  output << ";" << endl
+         << matrix << "(" << id2 << ", " << id1 << ") = "
+         << matrix << "(" << id1 << ", " << id2 << ");" << endl;
 }
 
 void
 ShocksStatement::writeCovarAndCorrShocks(ostream &output) const
 {
-  covar_and_corr_shocks_type::const_iterator it;
+  covar_and_corr_shocks_t::const_iterator it;
 
   for (it = covar_shocks.begin(); it != covar_shocks.end(); it++)
-    {
-      int id1 = symbol_table.getTypeSpecificID(it->first.first) + 1;
-      int id2 = symbol_table.getTypeSpecificID(it->first.second) + 1;
-      const NodeID value = it->second;
-      output << "M_.Sigma_e(" << id1 << ", " << id2 << ") = ";
-      value->writeOutput(output);
-      output << "; M_.Sigma_e(" << id2 << ", " << id1 << ") = M_.Sigma_e("
-             << id1 << ", " << id2 << ");\n";
-    }
+    writeCovarOrCorrShock(output, it, false);
 
   for (it = corr_shocks.begin(); it != corr_shocks.end(); it++)
-    {
-      int id1 = symbol_table.getTypeSpecificID(it->first.first) + 1;
-      int id2 = symbol_table.getTypeSpecificID(it->first.second) + 1;
-      const NodeID value = it->second;
-      output << "M_.Sigma_e(" << id1 << ", " << id2 << ") = ";
-      value->writeOutput(output);
-      output << "*sqrt(M_.Sigma_e(" << id1 << ", " << id1 << ")*M_.Sigma_e("
-             << id2 << ", " << id2 << ")); M_.Sigma_e(" << id2 << ", "
-             << id1 << ") = M_.Sigma_e(" << id1 << ", " << id2 << ");\n";
-    }
+    writeCovarOrCorrShock(output, it, true);
 }
 
-MShocksStatement::MShocksStatement(const det_shocks_type &det_shocks_arg,
+void
+ShocksStatement::checkPass(ModFileStructure &mod_file_struct)
+{
+  // Workaround for trac ticket #35
+  mod_file_struct.shocks_present = true;
+
+  // Determine if there is a calibrated measurement error
+  for (var_and_std_shocks_t::const_iterator it = var_shocks.begin();
+       it != var_shocks.end(); it++)
+    if (symbol_table.isObservedVariable(it->first))
+      mod_file_struct.calibrated_measurement_errors = true;
+
+  for (var_and_std_shocks_t::const_iterator it = std_shocks.begin();
+       it != std_shocks.end(); it++)
+    if (symbol_table.isObservedVariable(it->first))
+      mod_file_struct.calibrated_measurement_errors = true;
+
+  for (covar_and_corr_shocks_t::const_iterator it = covar_shocks.begin();
+       it != covar_shocks.end(); it++)
+    if (symbol_table.isObservedVariable(it->first.first)
+        || symbol_table.isObservedVariable(it->first.second))
+      mod_file_struct.calibrated_measurement_errors = true;
+
+  for (covar_and_corr_shocks_t::const_iterator it = corr_shocks.begin();
+       it != corr_shocks.end(); it++)
+    if (symbol_table.isObservedVariable(it->first.first)
+        || symbol_table.isObservedVariable(it->first.second))
+      mod_file_struct.calibrated_measurement_errors = true;
+}
+
+MShocksStatement::MShocksStatement(const det_shocks_t &det_shocks_arg,
                                    const SymbolTable &symbol_table_arg) :
   AbstractShocksStatement(true, det_shocks_arg, symbol_table_arg)
 {
@@ -185,7 +241,14 @@ MShocksStatement::writeOutput(ostream &output, const string &basename) const
   writeDetShocks(output);
 }
 
-ConditionalForecastPathsStatement::ConditionalForecastPathsStatement(const AbstractShocksStatement::det_shocks_type &paths_arg, const SymbolTable &symbol_table_arg) :
+void
+MShocksStatement::checkPass(ModFileStructure &mod_file_struct)
+{
+  // Workaround for trac ticket #35
+  mod_file_struct.shocks_present = true;
+}
+
+ConditionalForecastPathsStatement::ConditionalForecastPathsStatement(const AbstractShocksStatement::det_shocks_t &paths_arg, const SymbolTable &symbol_table_arg) :
   paths(paths_arg),
   symbol_table(symbol_table_arg),
   path_length(-1)
@@ -195,7 +258,7 @@ ConditionalForecastPathsStatement::ConditionalForecastPathsStatement(const Abstr
 void
 ConditionalForecastPathsStatement::checkPass(ModFileStructure &mod_file_struct)
 {
-  for (AbstractShocksStatement::det_shocks_type::const_iterator it = paths.begin();
+  for (AbstractShocksStatement::det_shocks_t::const_iterator it = paths.begin();
        it != paths.end(); it++)
     {
       int this_path_length = 0;
@@ -222,10 +285,14 @@ ConditionalForecastPathsStatement::writeOutput(ostream &output, const string &ba
 
   int k = 1;
 
-  for (AbstractShocksStatement::det_shocks_type::const_iterator it = paths.begin();
+  for (AbstractShocksStatement::det_shocks_t::const_iterator it = paths.begin();
        it != paths.end(); it++)
     {
-      output << "constrained_vars_ = strvcat(constrained_vars_, '" << it->first << "');" << endl;
+      if (it == paths.begin())
+        output << "constrained_vars_ = '" << it->first << "';" << endl;
+      else
+        output << "constrained_vars_ = char(constrained_vars_, '" << it->first << "');" << endl;
+
       const vector<AbstractShocksStatement::DetShockElement> &elems = it->second;
       for (int i = 0; i < (int) elems.size(); i++)
         for (int j = elems[i].period1; j <= elems[i].period2; j++)
